@@ -10,6 +10,11 @@
 #include <stdio.h>
 #include "postal.h"
 #include "logit.h"
+#ifdef USE_GNUTLS
+#include <errno.h>
+#include <gcrypt.h>
+GCRY_THREAD_OPTION_PTHREAD_IMPL;
+#endif
 
 void usage()
 {
@@ -18,13 +23,22 @@ void usage()
 #ifdef USE_SSL
          "             [-s ssl-percentage] [-d download-percentage[:delete-percentage]]\n"
 #endif
-         "             [-[z|Z] debug-file]\n"
-         "             pop-server user-list-filename conversion-filename\n"
+         "             [-[z|Z] debug-file] [-u]\n"
+         "             pop-server user-list-filename\n"
          "\n"
          "Rabid Version: " VER_STR "\n");
   exit(eParam);
 }
 
+int exitCount = 0;
+
+void endit(int)
+{
+  exitCount++;
+  if(exitCount > 2)
+    exit(1);
+}
+
 int main(int argc, char **argv)
 {
 
@@ -41,9 +55,19 @@ int main(int argc, char **argv)
   TRISTATE qmail_pop = eNONE;
   PCCHAR debugName = NULL;
   bool debugMultipleFiles = false;
+  bool strip_domain = false;
+#ifdef USE_GNUTLS
+  gcry_control(GCRYCTL_SET_THREAD_CBS, &gcry_threads_pthread);
+  gnutls_global_init();
+  if(!gnutls_check_version(GNUTLS_VER))
+  {
+    fprintf(stderr, "Needs version " GNUTLS_VER " of GNUTLS\n");
+    exit(1);
+  }
+#endif
 
   int c;
-  while(-1 != (c = getopt(argc, argv, "ab:d:c:i:l:p:r:s:z:Z:")) )
+  while(-1 != (c = getopt(argc, argv, "ab:d:c:i:l:p:r:s:uz:Z:")) )
   {
     switch(char(c))
     {
@@ -84,6 +108,9 @@ int main(int argc, char **argv)
         usage();
 #endif
       break;
+      case 'u':
+        strip_domain = true;
+      break;
       case 'Z':
         debugMultipleFiles = true;
       case 'z':
@@ -103,33 +130,40 @@ int main(int argc, char **argv)
     usage();
   if(deletePercent < 0 || deletePercent > 100)
     usage();
-  if(optind + 3 != argc)
+  if(optind + 2 != argc)
     usage();
 
-  UserList ul(argv[optind + 1]
-            , argv[optind + 2]
-            , true);
+  UserList ul(argv[optind + 1], true, strip_domain);
 
   struct sigaction sa;
-  sa.sa_handler = SIG_IGN;
   sa.sa_sigaction = NULL;
+  sa.sa_handler = SIG_IGN;
   sa.sa_flags = 0;
   if(sigaction(SIGPIPE, &sa, NULL))
   {
     printf("Can't block SIGPIPE.\n");
     return eSystem;
   }
+
+  sa.sa_flags = SA_SIGINFO;
+  sa.sa_handler = &endit;
+  if(sigaction(SIGINT, &sa, NULL))
+  {
+    printf("Can't handle SIGINT.\n");
+    return eSystem;
+  }
+
   printf("time,messages,data(K),errors,connections"
 #ifdef USE_SSL
-         ",SSL connections,"
+         ",SSL connections"
 #endif
-         "IMAP connections\n");
+         ",IMAP connections\n");
   Logit log("rabid.log", logAll, false, 0);
   Logit *debug = NULL;
  
   if(debugName)
     debug = new Logit(debugName, false, debugMultipleFiles, 0);
-  client popper(argv[optind], ourAddr, ul, processes, msgsPerConnection, &log
+  client popper(&exitCount, argv[optind], ourAddr, ul, processes, msgsPerConnection, &log
 #ifdef USE_SSL
               , ssl
 #endif
